@@ -26,7 +26,6 @@
 #include <libspi/action.h>
 #include <libspi/application.h>
 #include <libspi/component.h>
-#include <libspi/desktop.h>
 #include <libspi/editabletext.h>
 #include <libspi/hyperlink.h>
 #include <libspi/hypertext.h>
@@ -37,10 +36,9 @@
 #include <libspi/text.h>
 #include <libspi/value.h>
 #include <libspi/listener.h>
+#include <libspi/eventlistener.h>
 #include <libspi/keystrokelistener.h>
-#include <libspi/accessibleeventlistener.h>
-#include <libspi/deviceeventcontroller.h>
-#include <libspi/registry.h>
 #include <libspi/keymasks.h>
+#include <libspi/remoteobject.h>
 
 #endif /* LIBSPI_H_ */
